@@ -42,22 +42,6 @@ module.exports = {
               sourceMap: true,
             },
           },
-          {
-            loader: 'postcss-loader?sourceMap',
-            options: {
-              plugins: function () {
-                return [
-                  require('autoprefixer')
-                ]
-              },
-            },
-          },
-          {
-            loader: 'resolve-url-loader',
-            options: {
-              sourceMap: true
-            }
-          },
           {
             loader: 'sass-loader?sourceMap',
           },
